@@ -1,7 +1,5 @@
+# -*- coding: utf-8 -*-
 # Pitivi video editor
-#
-#       pitivi/autoaligner.py
-#
 # Copyright (c) 2011, Benjamin M. Schwartz <bens@alum.mit.edu>
 #
 # This program is free software; you can redistribute it and/or
@@ -18,18 +16,14 @@
 # License along with this program; if not, write to the
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 # Boston, MA 02110-1301, USA.
-
 # TODO reimplement after GES port
-"""
-Classes for automatic alignment of L{Clip}s
-"""
-
-from gi.repository import GObject
-from gi.repository import Gst
+"""Automatic alignment of `Clip`s."""
 import array
-import time
-from gi.repository import Gtk
 import os
+import time
+
+from gi.repository import Gst
+from gi.repository import Gtk
 
 
 try:
